[Bf-blender-cvs] [c5fd1ae] object_nodes: Merge branch 'master' into object_nodes

Lukas Tönne noreply at git.blender.org
Sun May 8 11:33:23 CEST 2016


Commit: c5fd1aeff22e54dbd916877443d2b4466b2679d7
Author: Lukas Tönne
Date:   Sun May 8 11:15:48 2016 +0200
Branches: object_nodes
https://developer.blender.org/rBc5fd1aeff22e54dbd916877443d2b4466b2679d7

Merge branch 'master' into object_nodes

===================================================================



===================================================================

diff --cc source/blender/blenkernel/intern/blender.c
index d787615,15492fb..2513676
--- a/source/blender/blenkernel/intern/blender.c
+++ b/source/blender/blenkernel/intern/blender.c
@@@ -79,10 -60,7 +60,9 @@@
  #include "BKE_scene.h"
  #include "BKE_screen.h"
  #include "BKE_sequencer.h"
- #include "BKE_sound.h"
  
 +#include "BVM_api.h"
 +
  #include "RE_pipeline.h"
  #include "RE_render_ext.h"
  
@@@ -132,10 -96,9 +98,10 @@@ void BKE_blender_free(void
  	IMB_moviecache_destruct();
  	
  	free_nodesystem();
 +	BVM_free();
  }
  
- void initglobals(void)
+ void BKE_blender_globals_init(void)
  {
  	memset(&G, 0, sizeof(Global));
  	
diff --cc source/gameengine/GamePlayer/ghost/GPG_ghost.cpp
index 9ab5515,a69a8ea..f1f91fe
--- a/source/gameengine/GamePlayer/ghost/GPG_ghost.cpp
+++ b/source/gameengine/GamePlayer/ghost/GPG_ghost.cpp
@@@ -456,11 -454,10 +456,11 @@@ int main(int argc, char** argv
  	RNA_init();
  
  	init_nodesystem();
 +	BVM_init();
  	
- 	initglobals();
+ 	BKE_blender_globals_init();
  
  	// We load our own G.main, so free the one that initglobals() gives us
  	BKE_main_free(G.main);
  	G.main = NULL;
@@@ -456,11 -454,10 +456,11 @@@ int main(int argc, char** argv
  
- 	// We load our own G.main, so free the one that initglobals() gives us
+ 	// We load our own G.main, so free the one that BKE_blender_globals_init() gives us
  	BKE_main_free(G.main);
  	G.main = NULL;




More information about the Bf-blender-cvs mailing list